@@ -16,6 +16,8 @@ describe 'vitrage::db::postgresql' do
         req_params
       end
 
+      it { is_expected.to contain_class('vitrage::deps') }
+
       it { is_expected.to contain_openstacklib__db__postgresql('vitrage').with(
         :user       => 'vitrage',
         :password   => 'vitragepass',
@@ -38,7 +40,10 @@ describe 'vitrage::db::postgresql' do
         }))
       end
 
-      it_configures 'vitrage::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_configures 'vitrage::db::postgresql'
+      end
     end
   end
 
